@@ -15,8 +15,8 @@ dimdescr <- function(resmca,vars=NULL,dim=c(1,2),min.cor=NULL,nperm=100,distrib=
    if(!is.null(vars)) X <- as.data.frame(vars)
    if(classe=='stMCA') classe=resmca$call$input.mca
    for(i in 1:length(dim)) {
-      if(classe %in% c('MCA','speMCA')) temp <- condesc(resmca$ind$coord[,i],X,weights=resmca$call$row.w,min.cor=min.cor,nperm=nperm,distrib=distrib,dec=c(3,3,3,3),robust=FALSE)
-      if(classe == 'csMCA') temp <- condesc(resmca$ind$coord[,i],X[resmca$call$subcloud,],weights=resmca$call$row.w[resmca$call$subcloud],min.cor=min.cor,nperm=nperm,distrib=distrib,dec=c(3,3,3,3),robust=FALSE)
+      if(classe %in% c('MCA','speMCA')) temp <- condesc(resmca$ind$coord[,dim[i]],X,weights=resmca$call$row.w,min.cor=min.cor,nperm=nperm,distrib=distrib,dec=c(3,3,3,3),robust=FALSE)
+      if(classe == 'csMCA') temp <- condesc(resmca$ind$coord[,dim[i]],X[resmca$call$subcloud,],weights=resmca$call$row.w[resmca$call$subcloud],min.cor=min.cor,nperm=nperm,distrib=distrib,dec=c(3,3,3,3),robust=FALSE)
       rownames(temp) <- NULL
       res[[i]] <- temp
       }
